==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/photos/l10n/fr.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Your memories under your control" : "Gardez le contrôle de vos souvenirs",
    "All media" : "Tous les médias",
    "Videos" : "Vidéos",
    "Albums" : "Albums",
    "Collaborative albums" : "Albums collaboratifs",
    "People" : "Personnes",
    "Folders" : "Dossiers",
    "Favorites" : "Favoris",
    "On this day" : "Ce même jour",
    "Shared with you" : "Partagé avec vous",
    "Tags" : "Étiquettes",
    "Locations" : "Lieux",
    "Photos settings" : "Paramètres des photos",
    "Mark selection as favorite" : "Marquer la sélection comme favorite",
    "Add selection to favorites" : "Ajouter la sélection aux favoris",
    "Remove selection from favorites" : "Retirer la sélection des favoris",
    "Name of the album" : "Nom de l'album",
    "Location of the album" : "Emplacement de l'album",
    "Go back to the previous view." : "Revenir à la vue précédente",
    "Back" : "Retour",
    "Go to the add collaborators view." : "Allez à la vue d'ajout de collaborateurs",
    "Add collaborators" : "Ajouter des collaborateurs",
    "Save." : "Enregistrer",
    "Create the album." : "Créer l'album",
    "Save" : "Enregistrer",
    "Create album" : "Créer un album",
    "Back to the new album form." : "Retour au formulaire de nouvel album",
    "Add to Album" : "Ajouter à l'album",
    "Add selection to album {ablumName}" : "Ajouter la sélection à l'album {ablumName}",
    "Create a new album." : "Créer un nouvel album",
    "Create new album" : "Créer un nouvel album",
    "New album" : "Nouvel album",
    "_%n item_::_%n photos and videos_" : ["%n élément","%n photos et vidéos","%n photos et vidéos"],
    "_Share with %n user_::_Share with %n users_" : ["Partager avec %n utilisateur","Partager avec %n utilisateurs","Partager avec %n utilisateurs"],
    "Add people or groups who can edit your album" : "Ajoutez des personnes ou des groupes qui peuvent modifier votre album",
    "Search for collaborators" : "Rechercher des collaborateurs",
    "Search people or groups" : "Recherche des personnes ou des groupes",
    "Add {collaboratorLabel} to the collaborators list" : "Ajouter {collaboratorLabel} à la liste des collaborateurs",
    "No collaborators available" : "Aucun collaborateur disponible",
    "Remove {collaboratorLabel} from the collaborators list" : "Supprimer {collaboratorLabel} de la liste des collaborateurs",
    "Public link copied!" : "Lien public copié !",
    "Copy public link" : "Copier le lien public",
    "Share via public link" : "Partager via un lien public",
    "Failed to fetch collaborators list." : "Échec de la récupération de la liste des collaborateurs.",
    "This collection does not exist" : "Cette collection n'existe pas",
    "An error occurred" : "Une erreur est survenue",
    "_%n photos_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "Select image {imageName}" : "Sélectionner l'image {imageName}",
    "The file is in the favorites" : "Le fichier se trouve dans les favoris",
    "Open the full size \"{name}\" image" : "Ouvrir l'image \"{name}\" dans sa taille originale",
    "There are no photos or videos yet!" : "Il n'y a pas encore de photos ou de vidéos !",
    "Add to {destination}" : "Ajouter à {destination}",
    "Open the \"{name}\" sub-directory" : "Ouvrir le sous-dossier \"{name}\"",
    "Back to {folder}" : "Revenir au dossier {folder}",
    "Share this folder" : "Partager ce dossier",
    "_{years} year ago_::_{years} years ago_" : ["Il y a {years} ans","Il y a {years} ans","Il y a {years} an(s)"],
    "Enable squared photos view" : "Activer l'affichage en miniatures carrées",
    "Default Photos upload and Albums location" : "Emplacement par défaut du téléversement des photos et des albums",
    "Select the default location for your media" : "Sélectionnez l'emplacement par défaut de vos médias",
    "Invalid location selected" : "Emplacement sélectionné non valide",
    "View" : "Affichage",
    "Photos directory" : "Répertoire des photos",
    "_%n photo_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "Manage collaborators for this album" : "Gérer les collaborateurs pour cet album",
    "Open actions menu" : "Ouvrir le menu des actions",
    "Edit album details" : "Modifier les détails de l'album",
    "Download all files in album" : "Télécharger tous les fichiers de l'album",
    "Delete album" : "Supprimer l'album",
    "Download selected files" : "Télécharger les fichiers sélectionnés",
    "Remove selection from album" : "Retirer la sélection de l'album",
    "This album does not have any photos or videos yet!" : "Cet album n'a pas encore de photos ou de vidéos !",
    "Add photos to this album" : "Ajouter des photos à cet album",
    "Add photos to the album" : "Ajouter des photos à l'album",
    "Manage collaborators" : "Gérer les collaborateurs",
    "Save collaborators for this album." : "Enregistrer les collaborateurs pour cet album.",
    "Cover photo for album {albumName}" : "Photo de couverture de l'album {albumName}",
    "There is no album yet!" : "Il n'y a pas encore d'album !",
    "This person could not be found" : "Cette personne n'a pas pu être trouvée",
    "Rename person" : "Renommer la personne",
    "Merge with different person" : "Fusionner avec une différente personne",
    "Download selected photos" : "Télécharger les photos sélectionnées",
    "Favorite" : "Favoris",
    "Remove from favorites" : "Retirer des favoris",
    "Remove person" : "Retirer la personne",
    "Name of this person" : "Nom de cette personne",
    "Merge person" : "Fusionner une personne",
    "_Remove photo from person_::_Remove photos from person_" : ["Supprimer la photo de la personne","Supprimer la photo de la personne","Supprimer les photos de la personne"],
    "This might take some time depending on the size of your photo library." : "Cela peut prendre un certain temps en fonction de la taille de votre photothèque.",
    "Recognized people will show up here" : "Les personnes reconnues apparaîtront ici",
    "This folder does not exist" : "Ce dossier n'existe pas",
    "Loading folders …" : "Chargement des dossiers ...",
    "No photos in here" : "Aucune photo",
    "Shared albums" : "Albums partagés",
    "Cover photo for shared album {albumName}." : "Photo de couverture pour l'album partagé {albumName}.",
    "Back to tags overview" : "Retour à l'aperçu des étiquettes",
    "No photos with this tag yet" : "Pas de photo avec cette étiquette pour l'instant",
    "No tags yet" : "Aucune étiquette pour le moment",
    "Photos with tags will show up here" : "Les photos étiquetées apparaîtront ici",
    "Popular tags" : "Étiquettes populaires",
    "Add" : "Ajouter",
    "Create a new album" : "Créer un nouvel album",
    "Add selection to an album" : "Ajouter la sélection à un album",
    "Add to album" : "Ajouter à l'album",
    "Delete selection" : "Supprimer la sélection",
    "Failed to fetch faces list." : "Échec de la récupération de la liste des visages.",
    "All your media" : "Tous vos médias",
    "Tagged photos" : "Photos étiquetées ",
    "Failed to create {albumName}." : "Échec de la création de {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Échec du renommage de {currentAlbumName} en {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Échec du renommage de {oldName} en {faceName}.",
    "Failed to delete {faceName}." : "Échec de la suppression de {faceName}.",
    "Failed to delete {fileId}." : "Échec de la suppression de {fileId}.",
    "Failed to delete {fileName}." : "Échec de la suppression de {fileName}.",
    "Failed to set favorite state for {fileId}." : "Impossible de définir l'état des favoris pour {fileId}.",
    "Failed to set favorite state for {fileName}." : "Échec de la définition de l'état des favoris pour {fileName}.",
    "Your photos" : "Vos photos",
    "Your videos" : "Vos vidéos",
    "Your folders" : "Vos dossiers",
    "Settings" : "Paramètres"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/photos/l10n/fr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Lien public",
    "Photos" : "Photos",
    "Your memories under your control" : "Gardez le contrôle de vos souvenirs",
    "All media" : "Tous les médias",
    "Videos" : "Vidéos",
    "Albums" : "Albums",
    "Collaborative albums" : "Albums collaboratifs",
    "People" : "Personnes",
    "Folders" : "Dossiers",
    "Favorites" : "Favoris",
    "On this day" : "Ce même jour",
    "Shared with you" : "Partagé avec vous",
    "Tags" : "Étiquettes",
    "Locations" : "Lieux",
    "Photos settings" : "Paramètres des photos",
    "Mark selection as favorite" : "Marquer la sélection comme favorite",
    "Add selection to favorites" : "Ajouter la sélection aux favoris",
    "Remove selection from favorites" : "Retirer la sélection des favoris",
    "Name of the album" : "Nom de l'album",
    "Location of the album" : "Emplacement de l'album",
    "Go back to the previous view." : "Revenir à la vue précédente",
    "Back" : "Retour",
    "Go to the add collaborators view." : "Allez à la vue d'ajout de collaborateurs",
    "Add collaborators" : "Ajouter des collaborateurs",
    "Save." : "Enregistrer",
    "Create the album." : "Créer l'album",
    "Save" : "Enregistrer",
    "Create album" : "Créer un album",
    "Back to the new album form." : "Retour au formulaire de nouvel album",
    "Add to Album" : "Ajouter à l'album",
    "Add selection to album {albumName}" : "Ajouter la sélection à l'album {albumName}",
    "Create a new album." : "Créer un nouvel album",
    "Create new album" : "Créer un nouvel album",
    "New album" : "Nouvel album",
    "_%n item_::_%n photos and videos_" : ["%n élément","%n photos et vidéos","%n photos et vidéos"],
    "_Share with %n user_::_Share with %n users_" : ["Partager avec %n utilisateur","Partager avec %n utilisateurs","Partager avec %n utilisateurs"],
    "Add people or groups who can edit your album" : "Ajoutez des personnes ou des groupes qui peuvent modifier votre album",
    "Search for collaborators" : "Rechercher des collaborateurs",
    "Search people or groups" : "Recherche des personnes ou des groupes",
    "Add {collaboratorLabel} to the collaborators list" : "Ajouter {collaboratorLabel} à la liste des collaborateurs",
    "No collaborators available" : "Aucun collaborateur disponible",
    "Remove {collaboratorLabel} from the collaborators list" : "Supprimer {collaboratorLabel} de la liste des collaborateurs",
    "Copy the public link" : "Copier le lien public",
    "Public link copied!" : "Lien public copié !",
    "Copy public link" : "Copier le lien public",
    "Delete the public link" : "Supprimer le lien public",
    "Share via public link" : "Partager via un lien public",
    "Failed to fetch collaborators list." : "Échec de la récupération de la liste des collaborateurs.",
    "Failed to fetch album." : "Impossible de récupérer l'album.",
    "Failed to update album." : "Impossible de mettre à jour de l'album.",
    "This collection does not exist" : "Cette collection n'existe pas",
    "An error occurred" : "Une erreur est survenue",
    "_%n photos_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "Select image {imageName}" : "Sélectionner l'image {imageName}",
    "The file is in the favorites" : "Le fichier se trouve dans les favoris",
    "Open the full size \"{name}\" image" : "Ouvrir l'image \"{name}\" dans sa taille originale",
    "There are no photos or videos yet!" : "Il n'y a pas encore de photos ou de vidéos !",
    "Add to {destination}" : "Ajouter à {destination}",
    "Open the \"{name}\" sub-directory" : "Ouvrir le sous-dossier \"{name}\"",
    "Back to {folder}" : "Revenir au dossier {folder}",
    "Share this folder" : "Partager ce dossier",
    "_{years} year ago_::_{years} years ago_" : ["Il y a {years} ans","Il y a {years} ans","Il y a {years} an(s)"],
    "Enable squared photos view" : "Activer l'affichage en miniatures carrées",
    "Default Photos upload and Albums location" : "Emplacement par défaut du téléversement des photos et des albums",
    "Select the default location for your media" : "Sélectionnez l'emplacement par défaut de vos médias",
    "Invalid location selected" : "Emplacement sélectionné non valide",
    "View" : "Affichage",
    "Photos directory" : "Dossier des photos",
    "_%n photo_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "Manage collaborators for this album" : "Gérer les collaborateurs pour cet album",
    "Open actions menu" : "Ouvrir le menu des actions",
    "Edit album details" : "Modifier les détails de l'album",
    "Download all files in album" : "Télécharger tous les fichiers de l'album",
    "Delete album" : "Supprimer l'album",
    "Download selected files" : "Télécharger les fichiers sélectionnés",
    "Remove selection from album" : "Retirer la sélection de l'album",
    "This album does not have any photos or videos yet!" : "Cet album n'a pas encore de photos ou de vidéos !",
    "Add photos to this album" : "Ajouter des photos à cet album",
    "Add photos to the album" : "Ajouter des photos à l'album",
    "Manage collaborators" : "Gérer les collaborateurs",
    "Save collaborators for this album." : "Enregistrer les collaborateurs pour cet album.",
    "Cover photo for album {albumName}" : "Photo de couverture de l'album {albumName}",
    "There is no album yet!" : "Il n'y a pas encore d'album !",
    "This person could not be found" : "Cette personne n'a pas pu être trouvée",
    "Rename person" : "Renommer la personne",
    "Merge with different person" : "Fusionner avec une différente personne",
    "Download selected photos" : "Télécharger les photos sélectionnées",
    "Favorite" : "Favoris",
    "Remove from favorites" : "Retirer des favoris",
    "Remove person" : "Retirer la personne",
    "Name of this person" : "Nom de cette personne",
    "Merge person" : "Fusionner une personne",
    "_Remove photo from person_::_Remove photos from person_" : ["Supprimer la photo de la personne","Supprimer la photo de la personne","Supprimer les photos de la personne"],
    "This might take some time depending on the size of your photo library." : "Cela peut prendre un certain temps en fonction de la taille de votre photothèque.",
    "Recognized people will show up here" : "Les personnes reconnues apparaîtront ici",
    "This folder does not exist" : "Ce dossier n'existe pas",
    "Loading folders …" : "Chargement des dossiers ...",
    "No photos in here" : "Aucune photo",
    "Failed to fetch albums list." : "Impossible de récupérer la liste des albums.",
    "Shared albums" : "Albums partagés",
    "Cover photo for shared album {albumName}." : "Photo de couverture pour l'album partagé {albumName}.",
    "Back to tags overview" : "Retour à l'aperçu des étiquettes",
    "No photos with this tag yet" : "Pas de photo avec cette étiquette pour l'instant",
    "No tags yet" : "Aucune étiquette pour le moment",
    "Photos with tags will show up here" : "Les photos étiquetées apparaîtront ici",
    "Popular tags" : "Étiquettes populaires",
    "Add" : "Ajouter",
    "Create a new album" : "Créer un nouvel album",
    "Add selection to an album" : "Ajouter la sélection à un album",
    "Add to album" : "Ajouter à l'album",
    "Delete selection" : "Supprimer la sélection",
    "Failed to fetch faces list." : "Échec de la récupération de la liste des visages.",
    "All your media" : "Tous vos médias",
    "Tagged photos" : "Photos étiquetées ",
    "Failed to create {albumName}." : "Échec de la création de {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Échec du renommage de {currentAlbumName} en {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Échec du renommage de {oldName} en {faceName}.",
    "Failed to delete {faceName}." : "Échec de la suppression de {faceName}.",
    "Failed to delete {fileId}." : "Échec de la suppression de {fileId}.",
    "Failed to delete {fileName}." : "Échec de la suppression de {fileName}.",
    "Failed to set favorite state for {fileId}." : "Impossible de définir l'état des favoris pour {fileId}.",
    "Failed to set favorite state for {fileName}." : "Échec de la définition de l'état des favoris pour {fileName}.",
    "Your photos" : "Vos photos",
    "Your videos" : "Vos vidéos",
    "Your folders" : "Vos dossiers",
    "Settings" : "Paramètres"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
